github

package
v0.9.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 8, 2026 License: MIT Imports: 18 Imported by: 0

Documentation

Overview

Package github will adapt GitHub and gh integrations.

Index

Constants

This section is empty.

Variables

var ErrDiffTooLarge = errors.New("github pull request diff is too large")

Functions

func ContextWithDiscoverySnapshot added in v0.8.0

func ContextWithDiscoverySnapshot(ctx context.Context, snapshot *DiscoverySnapshot) context.Context

func ErrorMessage

func ErrorMessage(err error) string

ErrorMessage returns the most useful user-facing text for a GitHub CLI/API error, including captured command output when the shell error message is only a generic exit-code summary.

func IsInaccessibleReviewRequestReviewerError added in v0.9.4

func IsInaccessibleReviewRequestReviewerError(err error) bool

func IsNotFoundError added in v0.8.0

func IsNotFoundError(err error) bool

func IsPullRequestNotFoundError

func IsPullRequestNotFoundError(err error) bool

IsPullRequestNotFoundError reports whether GitHub could not resolve the PR object, which usually means a queued reviewer loop is stale.

func IsTransientError

func IsTransientError(err error) bool

IsTransientError reports whether a GitHub CLI/API failure is likely caused by network or service flakiness and should be retried instead of treated as a terminal loop failure.

Types

type AddReviewThreadReplyInput

type AddReviewThreadReplyInput struct {
	Repo     string
	ThreadID string
	Body     string
	CWD      string
}

type BranchProtection added in v0.8.0

type BranchProtection struct {
	Enabled           bool
	HasRequiredChecks bool
	RequiredChecks    []string
}

type BranchProtectionInput added in v0.8.0

type BranchProtectionInput struct {
	Repo   string
	Branch string
	CWD    string
}

type CapturePullRequestSnapshotInput

type CapturePullRequestSnapshotInput struct {
	ProjectID  string
	Repo       string
	PRNumber   int64
	CWD        string
	CapturedAt string
}

type CloseIssueInput added in v0.7.1

type CloseIssueInput struct {
	Repo        string
	IssueNumber int64
	StateReason string
	CWD         string
}

type ClosePullRequestInput added in v0.7.1

type ClosePullRequestInput struct {
	Repo     string
	PRNumber int64
	CWD      string
}

type CommentInfo added in v0.8.0

type CommentInfo struct {
	ID                int64
	Author            string
	AuthorAssociation string
	Body              string
	CreatedAt         string
	UpdatedAt         string
	URL               string
}

type CompareBranchesInput added in v0.7.4

type CompareBranchesInput struct {
	Repo       string
	BaseBranch string
	HeadBranch string
	CWD        string
}

type CompareBranchesResult added in v0.7.4

type CompareBranchesResult struct {
	AheadBy      int
	BehindBy     int
	Status       string
	TotalCommits int
}

type CompareCommitsInput added in v0.7.5

type CompareCommitsInput struct {
	Repo string
	Base string
	Head string
	CWD  string
}

type CompareCommitsResult added in v0.7.5

type CompareCommitsResult struct {
	Status string
}

type CreateIssueReactionInput added in v0.8.0

type CreateIssueReactionInput struct {
	Repo        string
	IssueNumber int64
	CommentID   int64
	Content     string
	CWD         string
}

type CreatePullRequestInput

type CreatePullRequestInput struct {
	Repo       string
	HeadBranch string
	BaseBranch string
	Title      string
	Body       string
	CWD        string
}

type CreatePullRequestResult

type CreatePullRequestResult struct {
	Number int64
	URL    string
}

type CurrentUserIdentity added in v0.9.0

type CurrentUserIdentity struct {
	Login     string
	NumericID int64
}

type DeleteIssueCommentInput added in v0.9.0

type DeleteIssueCommentInput struct {
	Repo      string
	CommentID int64
	CWD       string
}

type DependencyIssue added in v0.8.0

type DependencyIssue struct {
	ID            int64
	Number        int64
	Title         string
	URL           string
	HTMLURL       string
	RepositoryURL string
	State         string
	StateReason   string
	Repository    IssueRepository
}

type DiscoverySnapshot added in v0.8.0

type DiscoverySnapshot struct {
	// contains filtered or unexported fields
}

func NewDiscoverySnapshot added in v0.8.0

func NewDiscoverySnapshot(gateway *Gateway, tick *DiscoveryTickState, options DiscoverySnapshotOptions) *DiscoverySnapshot

type DiscoverySnapshotOptions added in v0.8.0

type DiscoverySnapshotOptions struct {
	PullRequestLimit int
	IssueLimit       int
}

type DiscoveryTickState added in v0.8.0

type DiscoveryTickState struct {
	// contains filtered or unexported fields
}

func NewDiscoveryTickState added in v0.8.0

func NewDiscoveryTickState() *DiscoveryTickState

type EnableAutoMergeInput added in v0.8.0

type EnableAutoMergeInput struct {
	Repo     string
	PRNumber int64
	Strategy config.ReviewerAutoMergeStrategy
	HeadSHA  string
	CWD      string
}

type Gateway

type Gateway struct {
	// contains filtered or unexported fields
}

func New

func New(options Options) *Gateway

func (*Gateway) AddIssueAssignees

func (g *Gateway) AddIssueAssignees(ctx context.Context, input IssueAssigneesInput) error

func (*Gateway) AddIssueLabels added in v0.7.1

func (g *Gateway) AddIssueLabels(ctx context.Context, input IssueLabelsInput) error

func (*Gateway) AddIssueReaction added in v0.8.0

func (g *Gateway) AddIssueReaction(ctx context.Context, input CreateIssueReactionInput) error

func (*Gateway) AddPullRequestComment

func (g *Gateway) AddPullRequestComment(ctx context.Context, input PullRequestCommentInput) error

func (*Gateway) AddPullRequestLabels

func (g *Gateway) AddPullRequestLabels(ctx context.Context, input PullRequestLabelsInput) error

func (*Gateway) AddPullRequestReaction

func (g *Gateway) AddPullRequestReaction(ctx context.Context, input PullRequestReactionInput) error

func (*Gateway) AddPullRequestReviewers

func (g *Gateway) AddPullRequestReviewers(ctx context.Context, input PullRequestReviewersInput) error

func (*Gateway) AddReviewThreadReply

func (g *Gateway) AddReviewThreadReply(ctx context.Context, input AddReviewThreadReplyInput) error

func (*Gateway) CapturePullRequestSnapshot

func (g *Gateway) CapturePullRequestSnapshot(ctx context.Context, input CapturePullRequestSnapshotInput) (storage.PullRequestSnapshotRecord, error)

func (*Gateway) CloseIssue added in v0.7.1

func (g *Gateway) CloseIssue(ctx context.Context, input CloseIssueInput) error

func (*Gateway) ClosePullRequest added in v0.7.1

func (g *Gateway) ClosePullRequest(ctx context.Context, input ClosePullRequestInput) error

func (*Gateway) CompareBranches added in v0.7.4

func (g *Gateway) CompareBranches(ctx context.Context, input CompareBranchesInput) (CompareBranchesResult, error)

func (*Gateway) CompareCommits added in v0.7.5

func (g *Gateway) CompareCommits(ctx context.Context, input CompareCommitsInput) (CompareCommitsResult, error)

CompareCommits returns the GitHub compare API status between Base and Head (one of "identical", "ahead", "behind", "diverged"). It is used by the fixer to decide whether a previously-pushed fix commit is still reachable from the live PR head.

func (*Gateway) CreateIssueComment

func (g *Gateway) CreateIssueComment(ctx context.Context, input IssueCommentInput) (IssueCommentResult, error)

func (*Gateway) CreatePullRequest

func (g *Gateway) CreatePullRequest(ctx context.Context, input CreatePullRequestInput) (CreatePullRequestResult, error)

func (*Gateway) DeleteIssueComment added in v0.9.0

func (g *Gateway) DeleteIssueComment(ctx context.Context, input DeleteIssueCommentInput) error

func (*Gateway) DetectCurrentRepository

func (g *Gateway) DetectCurrentRepository(ctx context.Context, cwd string) (string, error)

func (*Gateway) EnableAutoMerge added in v0.8.0

func (g *Gateway) EnableAutoMerge(ctx context.Context, input EnableAutoMergeInput) error

func (*Gateway) FindAnyIssueNumber added in v0.8.0

func (g *Gateway) FindAnyIssueNumber(ctx context.Context, repo string, cwd string) (int64, error)

func (*Gateway) FindReviewMarker

func (g *Gateway) FindReviewMarker(ctx context.Context, input VerifyReviewMarkerInput) (ReviewMarkerResult, error)

func (*Gateway) GetBranchProtection added in v0.8.0

func (g *Gateway) GetBranchProtection(ctx context.Context, input BranchProtectionInput) (BranchProtection, error)

func (*Gateway) GetCurrentUserIdentity added in v0.9.0

func (g *Gateway) GetCurrentUserIdentity(ctx context.Context, cwd string) (CurrentUserIdentity, error)

func (*Gateway) GetCurrentUserLogin

func (g *Gateway) GetCurrentUserLogin(ctx context.Context, cwd string) (string, error)

func (*Gateway) GetCurrentUserLoginForRepo added in v0.8.0

func (g *Gateway) GetCurrentUserLoginForRepo(ctx context.Context, repo string, cwd string) (string, error)

func (*Gateway) GetIssueState added in v0.8.0

func (g *Gateway) GetIssueState(ctx context.Context, input ViewIssueInput) (IssueState, error)

func (*Gateway) GetPullRequestAuthor

func (g *Gateway) GetPullRequestAuthor(ctx context.Context, input ViewPullRequestInput) (string, error)

func (*Gateway) GetPullRequestDiff

func (g *Gateway) GetPullRequestDiff(ctx context.Context, input GetPullRequestDiffInput) (string, error)

func (*Gateway) GetPullRequestHeadAndAuthor

func (g *Gateway) GetPullRequestHeadAndAuthor(ctx context.Context, input ViewPullRequestInput) (PullRequestHeadAndAuthor, error)

func (*Gateway) GetPullRequestHeadSHA

func (g *Gateway) GetPullRequestHeadSHA(ctx context.Context, input ViewPullRequestInput) (string, error)

func (*Gateway) GetRepositoryPermission added in v0.8.0

func (g *Gateway) GetRepositoryPermission(ctx context.Context, input RepositoryPermissionInput) (string, error)

func (*Gateway) GetRepositorySettings added in v0.8.0

func (g *Gateway) GetRepositorySettings(ctx context.Context, input RepositorySettingsInput) (RepositorySettings, error)

func (*Gateway) HasReviewMarker

func (g *Gateway) HasReviewMarker(ctx context.Context, input VerifyReviewMarkerInput) (bool, error)

func (*Gateway) InitializeLabels

func (g *Gateway) InitializeLabels(ctx context.Context, input InitializeLabelsInput) (LabelInitResult, error)

func (*Gateway) IsAuthenticated

func (g *Gateway) IsAuthenticated(ctx context.Context, cwd, hostname string) (bool, error)

func (*Gateway) ListBlockedByIssues added in v0.8.0

func (g *Gateway) ListBlockedByIssues(ctx context.Context, input ViewIssueInput) ([]DependencyIssue, error)

func (*Gateway) ListBlockingIssues added in v0.8.0

func (g *Gateway) ListBlockingIssues(ctx context.Context, input ViewIssueInput) ([]DependencyIssue, error)

func (*Gateway) ListIssueBlockedBy added in v0.8.0

func (g *Gateway) ListIssueBlockedBy(ctx context.Context, input ListIssueBlockedByInput) ([]IssueDependency, error)

func (*Gateway) ListIssueComments added in v0.8.0

func (g *Gateway) ListIssueComments(ctx context.Context, input ViewIssueInput) ([]CommentInfo, error)

func (*Gateway) ListIssueReactions added in v0.8.0

func (g *Gateway) ListIssueReactions(ctx context.Context, input IssueReactionInput) ([]IssueReaction, error)

func (*Gateway) ListIssueTimeline added in v0.8.0

func (g *Gateway) ListIssueTimeline(ctx context.Context, input IssueTimelineInput) ([]map[string]any, error)

func (*Gateway) ListLinkedPullRequests added in v0.8.0

func (g *Gateway) ListLinkedPullRequests(ctx context.Context, input LinkedPullRequestsInput) ([]LinkedPullRequest, error)

func (*Gateway) ListOpenIssues

func (g *Gateway) ListOpenIssues(ctx context.Context, input ListOpenIssuesInput) ([]IssueSummary, error)

func (*Gateway) ListOpenPullRequests

func (g *Gateway) ListOpenPullRequests(ctx context.Context, input ListOpenPullRequestsInput) ([]PullRequestSummary, error)

func (*Gateway) ListPullRequestCheckRuns added in v0.9.0

func (g *Gateway) ListPullRequestCheckRuns(ctx context.Context, input PullRequestCheckRunsInput) (PullRequestCheckRuns, error)

func (*Gateway) ListPullRequestReviewState added in v0.8.0

func (g *Gateway) ListPullRequestReviewState(ctx context.Context, input PullRequestReviewStateInput) (PullRequestReviewState, error)

func (*Gateway) ListReviewRequestedPullRequests added in v0.9.6

func (g *Gateway) ListReviewRequestedPullRequests(ctx context.Context, input ListReviewRequestedPullRequestsInput) ([]PullRequestSummary, error)

func (*Gateway) ListReviewThreads

func (g *Gateway) ListReviewThreads(ctx context.Context, input ListReviewThreadsInput) ([]ReviewThread, error)

func (*Gateway) ListSubIssues added in v0.8.0

func (g *Gateway) ListSubIssues(ctx context.Context, input ViewIssueInput) ([]DependencyIssue, error)

func (*Gateway) RemoveIssueLabels added in v0.7.1

func (g *Gateway) RemoveIssueLabels(ctx context.Context, input IssueLabelsInput) error

func (*Gateway) RemovePullRequestLabels

func (g *Gateway) RemovePullRequestLabels(ctx context.Context, input PullRequestLabelsInput) error

func (*Gateway) RemovePullRequestReaction

func (g *Gateway) RemovePullRequestReaction(ctx context.Context, input PullRequestReactionInput) error

func (*Gateway) ResolveReviewThread

func (g *Gateway) ResolveReviewThread(ctx context.Context, input ResolveReviewThreadInput) error

func (*Gateway) SubmitReview

func (g *Gateway) SubmitReview(ctx context.Context, input SubmitReviewInput) error

func (*Gateway) UpdateIssueComment

func (g *Gateway) UpdateIssueComment(ctx context.Context, input UpdateIssueCommentInput) error

func (*Gateway) UpdatePullRequestBody added in v0.7.1

func (g *Gateway) UpdatePullRequestBody(ctx context.Context, input UpdatePullRequestBodyInput) error

func (*Gateway) UpdatePullRequestTitle

func (g *Gateway) UpdatePullRequestTitle(ctx context.Context, input UpdatePullRequestTitleInput) error

func (*Gateway) ViewIssue

func (g *Gateway) ViewIssue(ctx context.Context, input ViewIssueInput) (IssueDetail, error)

func (*Gateway) ViewPullRequest

func (g *Gateway) ViewPullRequest(ctx context.Context, input ViewPullRequestInput) (PullRequestDetail, error)

func (*Gateway) ViewPullRequestMergeWatch added in v0.9.0

func (g *Gateway) ViewPullRequestMergeWatch(ctx context.Context, input ViewPullRequestInput) (PullRequestDetail, error)

func (*Gateway) ViewReviewThread added in v0.7.4

func (g *Gateway) ViewReviewThread(ctx context.Context, input ViewReviewThreadInput) (ReviewThread, error)

type GetPullRequestDiffInput

type GetPullRequestDiffInput struct {
	Repo     string
	PRNumber int64
	CWD      string
}

type GitHubUser added in v0.9.0

type GitHubUser struct {
	Login string
	ID    int64
}

type InitializeLabelsInput

type InitializeLabelsInput struct {
	Repo   string
	CWD    string
	DryRun bool
}

type IssueAssigneesInput

type IssueAssigneesInput struct {
	Repo        string
	IssueNumber int64
	Assignees   []string
	CWD         string
}

type IssueCommentInput

type IssueCommentInput struct {
	Repo        string
	IssueNumber int64
	Body        string
	CWD         string
}

type IssueCommentResult

type IssueCommentResult struct {
	ID  int64
	URL string
}

type IssueDependency added in v0.8.0

type IssueDependency struct {
	Number int64
	Repo   string
}

type IssueDetail

type IssueDetail struct {
	Number            int64
	Title             string
	Body              string
	URL               string
	State             string
	StateReason       string
	CreatedAt         string
	UpdatedAt         string
	ClosedAt          string
	Author            string
	AuthorAssociation string
	Assignees         []string
	AssigneeUsers     []GitHubUser
	Labels            []string
	IsPullRequest     bool
	CommentCount      int
	Comments          []CommentInfo
}

type IssueLabelsInput added in v0.7.1

type IssueLabelsInput struct {
	Repo        string
	IssueNumber int64
	Labels      []string
	CWD         string
}

type IssueReaction added in v0.8.0

type IssueReaction struct {
	ID        int64
	Content   string
	UserLogin string
}

type IssueReactionInput added in v0.8.0

type IssueReactionInput struct {
	Repo        string
	IssueNumber int64
	CommentID   int64
	CWD         string
}

type IssueRepository added in v0.8.0

type IssueRepository struct {
	Name     string
	FullName string
	URL      string
	HTMLURL  string
}

type IssueState added in v0.8.0

type IssueState struct {
	State       string
	StateReason string
}

type IssueSummary

type IssueSummary struct {
	Number            int64
	Title             string
	Body              string
	URL               string
	State             string
	UpdatedAt         string
	Author            string
	AuthorAssociation string
	Assignees         []string
	AssigneeUsers     []GitHubUser
	Labels            []string
	IsPullRequest     bool
}

type IssueTimelineInput added in v0.8.0

type IssueTimelineInput struct {
	Repo        string
	IssueNumber int64
	CWD         string
}

type LabelDefinition

type LabelDefinition struct {
	Name        string `json:"name"`
	Color       string `json:"color"`
	Description string `json:"description"`
}

func StandardLooperLabels

func StandardLooperLabels() []LabelDefinition

type LabelInitItem

type LabelInitItem struct {
	Name        string `json:"name"`
	Status      string `json:"status"`
	Color       string `json:"color"`
	Description string `json:"description"`
	Error       string `json:"error,omitempty"`
}

type LabelInitResult

type LabelInitResult struct {
	Repo    string           `json:"repo"`
	DryRun  bool             `json:"dryRun"`
	Labels  []LabelInitItem  `json:"labels"`
	Summary LabelInitSummary `json:"summary"`
}

type LabelInitSummary

type LabelInitSummary struct {
	Created int `json:"created"`
	Updated int `json:"updated"`
	Skipped int `json:"skipped"`
	Failed  int `json:"failed"`
}

type LinkedPullRequest added in v0.8.0

type LinkedPullRequest struct {
	Number         int64
	State          string
	Merged         bool
	MergedAt       string
	MergeCommitSHA string
}

type LinkedPullRequestsInput added in v0.8.0

type LinkedPullRequestsInput struct {
	Repo        string
	IssueNumber int64
	CWD         string
}

type ListIssueBlockedByInput added in v0.8.0

type ListIssueBlockedByInput struct {
	Repo        string
	IssueNumber int64
	CWD         string
}

type ListOpenIssuesInput

type ListOpenIssuesInput struct {
	Repo     string
	CWD      string
	Limit    int
	Assignee string
	Label    string
	Labels   []string
}

type ListOpenPullRequestsInput

type ListOpenPullRequestsInput struct {
	Repo        string
	CWD         string
	Limit       int
	Label       string
	Labels      []string
	Author      string
	BaseRefName string
	Timeout     time.Duration
}

type ListReviewRequestedPullRequestsInput added in v0.9.6

type ListReviewRequestedPullRequestsInput struct {
	Repo     string
	CWD      string
	Limit    int
	Reviewer string
	Timeout  time.Duration
}

type ListReviewThreadsInput

type ListReviewThreadsInput struct {
	Repo     string
	PRNumber int64
	CWD      string
	Limit    int
}

type Options

type Options struct {
	GHPath                 string
	CWD                    string
	Now                    func() time.Time
	DiscoveryCacheTTL      time.Duration
	GHRun                  func(context.Context, shell.Options) (shell.Result, error)
	ReviewSubmitDiagnostic func(event string, fields map[string]any)
}

type PullRequestAutoMerge added in v0.9.0

type PullRequestAutoMerge struct {
	EnabledBy   string
	MergeMethod string
}

type PullRequestCheckRun added in v0.9.0

type PullRequestCheckRun struct {
	Name       string
	Status     string
	Conclusion string
}

type PullRequestCheckRuns added in v0.9.0

type PullRequestCheckRuns struct {
	TotalCount int
	CheckRuns  []PullRequestCheckRun
	Statuses   []PullRequestStatus
}

type PullRequestCheckRunsInput added in v0.9.0

type PullRequestCheckRunsInput struct {
	Repo string
	Ref  string
	CWD  string
}

type PullRequestCommentInput

type PullRequestCommentInput struct {
	Repo     string
	PRNumber int64
	Body     string
	CWD      string
}

type PullRequestDetail

type PullRequestDetail struct {
	Number             int64
	Title              string
	Body               string
	URL                string
	State              string
	CreatedAt          string
	UpdatedAt          string
	ClosedAt           string
	IsDraft            bool
	ReviewDecision     string
	Labels             []string
	HeadRefName        string
	BaseRefName        string
	HeadSHA            string
	BaseSHA            string
	Author             string
	AuthorAssociation  string
	CommentCount       int
	ReviewRequests     []string
	ReviewRequestUsers []GitHubUser
	HasConflicts       bool
	Comments           []map[string]any
	IssueComments      []CommentInfo
	Reviews            []map[string]any
	Checks             []map[string]any
	Mergeable          *bool
	MergeableState     string
	MergedAt           string
	AutoMerge          *PullRequestAutoMerge
}

type PullRequestHeadAndAuthor

type PullRequestHeadAndAuthor struct {
	HeadSHA string
	Author  string
}

type PullRequestLabelsInput

type PullRequestLabelsInput struct {
	Repo     string
	PRNumber int64
	Labels   []string
	CWD      string
}

type PullRequestReactionInput

type PullRequestReactionInput struct {
	Repo     string
	PRNumber int64
	Content  string
	CWD      string
}

type PullRequestReviewState added in v0.8.0

type PullRequestReviewState struct {
	RequestedReviewers  []string
	LatestReviewPerUser map[string]string
	LastReviewAt        string
}

type PullRequestReviewStateInput added in v0.8.0

type PullRequestReviewStateInput struct {
	Repo     string
	PRNumber int64
	CWD      string
}

type PullRequestReviewersInput

type PullRequestReviewersInput struct {
	Repo      string
	PRNumber  int64
	Reviewers []string
	CWD       string
}

type PullRequestStatus added in v0.9.0

type PullRequestStatus struct {
	Context string
	State   string
}

type PullRequestSummary

type PullRequestSummary struct {
	Number             int64
	Title              string
	URL                string
	State              string
	UpdatedAt          string
	IsDraft            bool
	ReviewDecision     string
	Labels             []string
	HeadRefName        string
	BaseRefName        string
	HeadSHA            string
	BaseSHA            string
	HasConflicts       bool
	Author             string
	AuthorAssociation  string
	ReviewRequests     []string
	ReviewRequestUsers []GitHubUser
	Reviews            []map[string]any
}

type RepositoryPermissionInput added in v0.8.0

type RepositoryPermissionInput struct {
	Repo string
	User string
	CWD  string
}

type RepositorySettings added in v0.8.0

type RepositorySettings struct {
	AllowSquashMerge bool
	AllowMergeCommit bool
	AllowRebaseMerge bool
	AllowAutoMerge   bool
}

type RepositorySettingsInput added in v0.8.0

type RepositorySettingsInput struct {
	Repo string
	CWD  string
}

type ResolveReviewThreadInput

type ResolveReviewThreadInput struct {
	Repo     string
	ThreadID string
	CWD      string
}

type ReviewComment

type ReviewComment struct {
	Body            string
	Path            string
	Line            int64
	Side            string
	StartLine       int64
	StartSide       string
	DiagnosticIndex int
}

type ReviewMarkerResult

type ReviewMarkerResult struct {
	Found               bool
	Outcome             string
	Event               string
	AuthorLogin         string
	Body                string
	ReviewID            string
	InlineCommentBodies []string
}

type ReviewThread

type ReviewThread struct {
	ID         string
	IsResolved bool
	Path       string
	Line       int64
	URL        string
	Comments   []ReviewThreadComment
}

type ReviewThreadComment

type ReviewThreadComment struct {
	ID                string
	Body              string
	Author            string
	AuthorAssociation string
	CreatedAt         string
	UpdatedAt         string
	Path              string
	Line              int64
	OriginalCommitOID string
	CommitOID         string
	URL               string
}

type ReviewThreadNotFoundError

type ReviewThreadNotFoundError struct {
	ThreadID string
}

func (*ReviewThreadNotFoundError) Error

func (e *ReviewThreadNotFoundError) Error() string

type SubmitReviewInput

type SubmitReviewInput struct {
	Repo       string
	PRNumber   int64
	Event      string
	Body       string
	CommitID   string
	Comments   []ReviewComment
	Anchors    *diffanchor.Index
	Disclosure config.DisclosureConfig
	CWD        string
}

type TransientError

type TransientError struct {
	Err error
}

func (*TransientError) Error

func (e *TransientError) Error() string

func (*TransientError) Unwrap

func (e *TransientError) Unwrap() error

type UpdateIssueCommentInput

type UpdateIssueCommentInput struct {
	Repo      string
	CommentID int64
	Body      string
	CWD       string
}

type UpdatePullRequestBodyInput added in v0.7.1

type UpdatePullRequestBodyInput struct {
	Repo     string
	PRNumber int64
	Body     string
	CWD      string
}

type UpdatePullRequestTitleInput

type UpdatePullRequestTitleInput struct {
	Repo     string
	PRNumber int64
	Title    string
	CWD      string
}

type VerifyReviewMarkerInput

type VerifyReviewMarkerInput struct {
	Repo                string
	PRNumber            int64
	Marker              string
	AllowedReviewEvents []string
	AuthorLogin         string
	AllowCleanComment   bool
	CWD                 string
}

type ViewIssueInput

type ViewIssueInput struct {
	Repo        string
	IssueNumber int64
	CWD         string
}

type ViewPullRequestInput

type ViewPullRequestInput struct {
	Repo     string
	PRNumber int64
	CWD      string
}

type ViewReviewThreadInput added in v0.7.4

type ViewReviewThreadInput struct {
	ThreadID string
	CWD      string
}

Jump to