Documentation
¶
Overview ¶
Package github will adapt GitHub and gh integrations.
Index ¶
- Variables
- func ContextWithDiscoverySnapshot(ctx context.Context, snapshot *DiscoverySnapshot) context.Context
- func ErrorMessage(err error) string
- func IsInaccessibleReviewRequestReviewerError(err error) bool
- func IsNotFoundError(err error) bool
- func IsPullRequestNotFoundError(err error) bool
- func IsTransientError(err error) bool
- type AddReviewThreadReplyInput
- type BranchProtection
- type BranchProtectionInput
- type CapturePullRequestSnapshotInput
- type CloseIssueInput
- type ClosePullRequestInput
- type CommentInfo
- type CompareBranchesInput
- type CompareBranchesResult
- type CompareCommitsInput
- type CompareCommitsResult
- type CreateIssueReactionInput
- type CreatePullRequestInput
- type CreatePullRequestResult
- type CurrentUserIdentity
- type DeleteIssueCommentInput
- type DependencyIssue
- type DiscoverySnapshot
- type DiscoverySnapshotOptions
- type DiscoveryTickState
- type EnableAutoMergeInput
- type Gateway
- func (g *Gateway) AddIssueAssignees(ctx context.Context, input IssueAssigneesInput) error
- func (g *Gateway) AddIssueLabels(ctx context.Context, input IssueLabelsInput) error
- func (g *Gateway) AddIssueReaction(ctx context.Context, input CreateIssueReactionInput) error
- func (g *Gateway) AddPullRequestComment(ctx context.Context, input PullRequestCommentInput) error
- func (g *Gateway) AddPullRequestLabels(ctx context.Context, input PullRequestLabelsInput) error
- func (g *Gateway) AddPullRequestReaction(ctx context.Context, input PullRequestReactionInput) error
- func (g *Gateway) AddPullRequestReviewers(ctx context.Context, input PullRequestReviewersInput) error
- func (g *Gateway) AddReviewThreadReply(ctx context.Context, input AddReviewThreadReplyInput) error
- func (g *Gateway) CapturePullRequestSnapshot(ctx context.Context, input CapturePullRequestSnapshotInput) (storage.PullRequestSnapshotRecord, error)
- func (g *Gateway) CloseIssue(ctx context.Context, input CloseIssueInput) error
- func (g *Gateway) ClosePullRequest(ctx context.Context, input ClosePullRequestInput) error
- func (g *Gateway) CompareBranches(ctx context.Context, input CompareBranchesInput) (CompareBranchesResult, error)
- func (g *Gateway) CompareCommits(ctx context.Context, input CompareCommitsInput) (CompareCommitsResult, error)
- func (g *Gateway) CreateIssueComment(ctx context.Context, input IssueCommentInput) (IssueCommentResult, error)
- func (g *Gateway) CreatePullRequest(ctx context.Context, input CreatePullRequestInput) (CreatePullRequestResult, error)
- func (g *Gateway) DeleteIssueComment(ctx context.Context, input DeleteIssueCommentInput) error
- func (g *Gateway) DetectCurrentRepository(ctx context.Context, cwd string) (string, error)
- func (g *Gateway) EnableAutoMerge(ctx context.Context, input EnableAutoMergeInput) error
- func (g *Gateway) FindAnyIssueNumber(ctx context.Context, repo string, cwd string) (int64, error)
- func (g *Gateway) FindReviewMarker(ctx context.Context, input VerifyReviewMarkerInput) (ReviewMarkerResult, error)
- func (g *Gateway) GetBranchProtection(ctx context.Context, input BranchProtectionInput) (BranchProtection, error)
- func (g *Gateway) GetCurrentUserIdentity(ctx context.Context, cwd string) (CurrentUserIdentity, error)
- func (g *Gateway) GetCurrentUserLogin(ctx context.Context, cwd string) (string, error)
- func (g *Gateway) GetCurrentUserLoginForRepo(ctx context.Context, repo string, cwd string) (string, error)
- func (g *Gateway) GetIssueState(ctx context.Context, input ViewIssueInput) (IssueState, error)
- func (g *Gateway) GetPullRequestAuthor(ctx context.Context, input ViewPullRequestInput) (string, error)
- func (g *Gateway) GetPullRequestDiff(ctx context.Context, input GetPullRequestDiffInput) (string, error)
- func (g *Gateway) GetPullRequestHeadAndAuthor(ctx context.Context, input ViewPullRequestInput) (PullRequestHeadAndAuthor, error)
- func (g *Gateway) GetPullRequestHeadSHA(ctx context.Context, input ViewPullRequestInput) (string, error)
- func (g *Gateway) GetRepositoryPermission(ctx context.Context, input RepositoryPermissionInput) (string, error)
- func (g *Gateway) GetRepositorySettings(ctx context.Context, input RepositorySettingsInput) (RepositorySettings, error)
- func (g *Gateway) HasReviewMarker(ctx context.Context, input VerifyReviewMarkerInput) (bool, error)
- func (g *Gateway) InitializeLabels(ctx context.Context, input InitializeLabelsInput) (LabelInitResult, error)
- func (g *Gateway) IsAuthenticated(ctx context.Context, cwd, hostname string) (bool, error)
- func (g *Gateway) ListBlockedByIssues(ctx context.Context, input ViewIssueInput) ([]DependencyIssue, error)
- func (g *Gateway) ListBlockingIssues(ctx context.Context, input ViewIssueInput) ([]DependencyIssue, error)
- func (g *Gateway) ListIssueBlockedBy(ctx context.Context, input ListIssueBlockedByInput) ([]IssueDependency, error)
- func (g *Gateway) ListIssueComments(ctx context.Context, input ViewIssueInput) ([]CommentInfo, error)
- func (g *Gateway) ListIssueReactions(ctx context.Context, input IssueReactionInput) ([]IssueReaction, error)
- func (g *Gateway) ListIssueTimeline(ctx context.Context, input IssueTimelineInput) ([]map[string]any, error)
- func (g *Gateway) ListLinkedPullRequests(ctx context.Context, input LinkedPullRequestsInput) ([]LinkedPullRequest, error)
- func (g *Gateway) ListOpenIssues(ctx context.Context, input ListOpenIssuesInput) ([]IssueSummary, error)
- func (g *Gateway) ListOpenPullRequests(ctx context.Context, input ListOpenPullRequestsInput) ([]PullRequestSummary, error)
- func (g *Gateway) ListPullRequestCheckRuns(ctx context.Context, input PullRequestCheckRunsInput) (PullRequestCheckRuns, error)
- func (g *Gateway) ListPullRequestReviewState(ctx context.Context, input PullRequestReviewStateInput) (PullRequestReviewState, error)
- func (g *Gateway) ListReviewRequestedPullRequests(ctx context.Context, input ListReviewRequestedPullRequestsInput) ([]PullRequestSummary, error)
- func (g *Gateway) ListReviewThreads(ctx context.Context, input ListReviewThreadsInput) ([]ReviewThread, error)
- func (g *Gateway) ListSubIssues(ctx context.Context, input ViewIssueInput) ([]DependencyIssue, error)
- func (g *Gateway) RemoveIssueLabels(ctx context.Context, input IssueLabelsInput) error
- func (g *Gateway) RemovePullRequestLabels(ctx context.Context, input PullRequestLabelsInput) error
- func (g *Gateway) RemovePullRequestReaction(ctx context.Context, input PullRequestReactionInput) error
- func (g *Gateway) ResolveReviewThread(ctx context.Context, input ResolveReviewThreadInput) error
- func (g *Gateway) SubmitReview(ctx context.Context, input SubmitReviewInput) error
- func (g *Gateway) UpdateIssueComment(ctx context.Context, input UpdateIssueCommentInput) error
- func (g *Gateway) UpdatePullRequestBody(ctx context.Context, input UpdatePullRequestBodyInput) error
- func (g *Gateway) UpdatePullRequestTitle(ctx context.Context, input UpdatePullRequestTitleInput) error
- func (g *Gateway) ViewIssue(ctx context.Context, input ViewIssueInput) (IssueDetail, error)
- func (g *Gateway) ViewPullRequest(ctx context.Context, input ViewPullRequestInput) (PullRequestDetail, error)
- func (g *Gateway) ViewPullRequestMergeWatch(ctx context.Context, input ViewPullRequestInput) (PullRequestDetail, error)
- func (g *Gateway) ViewReviewThread(ctx context.Context, input ViewReviewThreadInput) (ReviewThread, error)
- type GetPullRequestDiffInput
- type GitHubUser
- type InitializeLabelsInput
- type IssueAssigneesInput
- type IssueCommentInput
- type IssueCommentResult
- type IssueDependency
- type IssueDetail
- type IssueLabelsInput
- type IssueReaction
- type IssueReactionInput
- type IssueRepository
- type IssueState
- type IssueSummary
- type IssueTimelineInput
- type LabelDefinition
- type LabelInitItem
- type LabelInitResult
- type LabelInitSummary
- type LinkedPullRequest
- type LinkedPullRequestsInput
- type ListIssueBlockedByInput
- type ListOpenIssuesInput
- type ListOpenPullRequestsInput
- type ListReviewRequestedPullRequestsInput
- type ListReviewThreadsInput
- type Options
- type PullRequestAutoMerge
- type PullRequestCheckRun
- type PullRequestCheckRuns
- type PullRequestCheckRunsInput
- type PullRequestCommentInput
- type PullRequestDetail
- type PullRequestHeadAndAuthor
- type PullRequestLabelsInput
- type PullRequestReactionInput
- type PullRequestReviewState
- type PullRequestReviewStateInput
- type PullRequestReviewersInput
- type PullRequestStatus
- type PullRequestSummary
- type RepositoryPermissionInput
- type RepositorySettings
- type RepositorySettingsInput
- type ResolveReviewThreadInput
- type ReviewComment
- type ReviewMarkerResult
- type ReviewThread
- type ReviewThreadComment
- type ReviewThreadNotFoundError
- type SubmitReviewInput
- type TransientError
- type UpdateIssueCommentInput
- type UpdatePullRequestBodyInput
- type UpdatePullRequestTitleInput
- type VerifyReviewMarkerInput
- type ViewIssueInput
- type ViewPullRequestInput
- type ViewReviewThreadInput
Constants ¶
This section is empty.
Variables ¶
var ErrDiffTooLarge = errors.New("github pull request diff is too large")
Functions ¶
func ContextWithDiscoverySnapshot ¶ added in v0.8.0
func ContextWithDiscoverySnapshot(ctx context.Context, snapshot *DiscoverySnapshot) context.Context
func ErrorMessage ¶
ErrorMessage returns the most useful user-facing text for a GitHub CLI/API error, including captured command output when the shell error message is only a generic exit-code summary.
func IsInaccessibleReviewRequestReviewerError ¶ added in v0.9.4
func IsNotFoundError ¶ added in v0.8.0
func IsPullRequestNotFoundError ¶
IsPullRequestNotFoundError reports whether GitHub could not resolve the PR object, which usually means a queued reviewer loop is stale.
func IsTransientError ¶
IsTransientError reports whether a GitHub CLI/API failure is likely caused by network or service flakiness and should be retried instead of treated as a terminal loop failure.
Types ¶
type BranchProtection ¶ added in v0.8.0
type BranchProtectionInput ¶ added in v0.8.0
type CloseIssueInput ¶ added in v0.7.1
type ClosePullRequestInput ¶ added in v0.7.1
type CommentInfo ¶ added in v0.8.0
type CompareBranchesInput ¶ added in v0.7.4
type CompareBranchesResult ¶ added in v0.7.4
type CompareCommitsInput ¶ added in v0.7.5
type CompareCommitsResult ¶ added in v0.7.5
type CompareCommitsResult struct {
Status string
}
type CreateIssueReactionInput ¶ added in v0.8.0
type CreatePullRequestInput ¶
type CreatePullRequestResult ¶
type CurrentUserIdentity ¶ added in v0.9.0
type DeleteIssueCommentInput ¶ added in v0.9.0
type DependencyIssue ¶ added in v0.8.0
type DiscoverySnapshot ¶ added in v0.8.0
type DiscoverySnapshot struct {
// contains filtered or unexported fields
}
func NewDiscoverySnapshot ¶ added in v0.8.0
func NewDiscoverySnapshot(gateway *Gateway, tick *DiscoveryTickState, options DiscoverySnapshotOptions) *DiscoverySnapshot
type DiscoverySnapshotOptions ¶ added in v0.8.0
type DiscoveryTickState ¶ added in v0.8.0
type DiscoveryTickState struct {
// contains filtered or unexported fields
}
func NewDiscoveryTickState ¶ added in v0.8.0
func NewDiscoveryTickState() *DiscoveryTickState
type EnableAutoMergeInput ¶ added in v0.8.0
type Gateway ¶
type Gateway struct {
// contains filtered or unexported fields
}
func (*Gateway) AddIssueAssignees ¶
func (g *Gateway) AddIssueAssignees(ctx context.Context, input IssueAssigneesInput) error
func (*Gateway) AddIssueLabels ¶ added in v0.7.1
func (g *Gateway) AddIssueLabels(ctx context.Context, input IssueLabelsInput) error
func (*Gateway) AddIssueReaction ¶ added in v0.8.0
func (g *Gateway) AddIssueReaction(ctx context.Context, input CreateIssueReactionInput) error
func (*Gateway) AddPullRequestComment ¶
func (g *Gateway) AddPullRequestComment(ctx context.Context, input PullRequestCommentInput) error
func (*Gateway) AddPullRequestLabels ¶
func (g *Gateway) AddPullRequestLabels(ctx context.Context, input PullRequestLabelsInput) error
func (*Gateway) AddPullRequestReaction ¶
func (g *Gateway) AddPullRequestReaction(ctx context.Context, input PullRequestReactionInput) error
func (*Gateway) AddPullRequestReviewers ¶
func (g *Gateway) AddPullRequestReviewers(ctx context.Context, input PullRequestReviewersInput) error
func (*Gateway) AddReviewThreadReply ¶
func (g *Gateway) AddReviewThreadReply(ctx context.Context, input AddReviewThreadReplyInput) error
func (*Gateway) CapturePullRequestSnapshot ¶
func (g *Gateway) CapturePullRequestSnapshot(ctx context.Context, input CapturePullRequestSnapshotInput) (storage.PullRequestSnapshotRecord, error)
func (*Gateway) CloseIssue ¶ added in v0.7.1
func (g *Gateway) CloseIssue(ctx context.Context, input CloseIssueInput) error
func (*Gateway) ClosePullRequest ¶ added in v0.7.1
func (g *Gateway) ClosePullRequest(ctx context.Context, input ClosePullRequestInput) error
func (*Gateway) CompareBranches ¶ added in v0.7.4
func (g *Gateway) CompareBranches(ctx context.Context, input CompareBranchesInput) (CompareBranchesResult, error)
func (*Gateway) CompareCommits ¶ added in v0.7.5
func (g *Gateway) CompareCommits(ctx context.Context, input CompareCommitsInput) (CompareCommitsResult, error)
CompareCommits returns the GitHub compare API status between Base and Head (one of "identical", "ahead", "behind", "diverged"). It is used by the fixer to decide whether a previously-pushed fix commit is still reachable from the live PR head.
func (*Gateway) CreateIssueComment ¶
func (g *Gateway) CreateIssueComment(ctx context.Context, input IssueCommentInput) (IssueCommentResult, error)
func (*Gateway) CreatePullRequest ¶
func (g *Gateway) CreatePullRequest(ctx context.Context, input CreatePullRequestInput) (CreatePullRequestResult, error)
func (*Gateway) DeleteIssueComment ¶ added in v0.9.0
func (g *Gateway) DeleteIssueComment(ctx context.Context, input DeleteIssueCommentInput) error
func (*Gateway) DetectCurrentRepository ¶
func (*Gateway) EnableAutoMerge ¶ added in v0.8.0
func (g *Gateway) EnableAutoMerge(ctx context.Context, input EnableAutoMergeInput) error
func (*Gateway) FindAnyIssueNumber ¶ added in v0.8.0
func (*Gateway) FindReviewMarker ¶
func (g *Gateway) FindReviewMarker(ctx context.Context, input VerifyReviewMarkerInput) (ReviewMarkerResult, error)
func (*Gateway) GetBranchProtection ¶ added in v0.8.0
func (g *Gateway) GetBranchProtection(ctx context.Context, input BranchProtectionInput) (BranchProtection, error)
func (*Gateway) GetCurrentUserIdentity ¶ added in v0.9.0
func (*Gateway) GetCurrentUserLogin ¶
func (*Gateway) GetCurrentUserLoginForRepo ¶ added in v0.8.0
func (*Gateway) GetIssueState ¶ added in v0.8.0
func (g *Gateway) GetIssueState(ctx context.Context, input ViewIssueInput) (IssueState, error)
func (*Gateway) GetPullRequestAuthor ¶
func (*Gateway) GetPullRequestDiff ¶
func (*Gateway) GetPullRequestHeadAndAuthor ¶
func (g *Gateway) GetPullRequestHeadAndAuthor(ctx context.Context, input ViewPullRequestInput) (PullRequestHeadAndAuthor, error)
func (*Gateway) GetPullRequestHeadSHA ¶
func (*Gateway) GetRepositoryPermission ¶ added in v0.8.0
func (*Gateway) GetRepositorySettings ¶ added in v0.8.0
func (g *Gateway) GetRepositorySettings(ctx context.Context, input RepositorySettingsInput) (RepositorySettings, error)
func (*Gateway) HasReviewMarker ¶
func (*Gateway) InitializeLabels ¶
func (g *Gateway) InitializeLabels(ctx context.Context, input InitializeLabelsInput) (LabelInitResult, error)
func (*Gateway) IsAuthenticated ¶
func (*Gateway) ListBlockedByIssues ¶ added in v0.8.0
func (g *Gateway) ListBlockedByIssues(ctx context.Context, input ViewIssueInput) ([]DependencyIssue, error)
func (*Gateway) ListBlockingIssues ¶ added in v0.8.0
func (g *Gateway) ListBlockingIssues(ctx context.Context, input ViewIssueInput) ([]DependencyIssue, error)
func (*Gateway) ListIssueBlockedBy ¶ added in v0.8.0
func (g *Gateway) ListIssueBlockedBy(ctx context.Context, input ListIssueBlockedByInput) ([]IssueDependency, error)
func (*Gateway) ListIssueComments ¶ added in v0.8.0
func (g *Gateway) ListIssueComments(ctx context.Context, input ViewIssueInput) ([]CommentInfo, error)
func (*Gateway) ListIssueReactions ¶ added in v0.8.0
func (g *Gateway) ListIssueReactions(ctx context.Context, input IssueReactionInput) ([]IssueReaction, error)
func (*Gateway) ListIssueTimeline ¶ added in v0.8.0
func (*Gateway) ListLinkedPullRequests ¶ added in v0.8.0
func (g *Gateway) ListLinkedPullRequests(ctx context.Context, input LinkedPullRequestsInput) ([]LinkedPullRequest, error)
func (*Gateway) ListOpenIssues ¶
func (g *Gateway) ListOpenIssues(ctx context.Context, input ListOpenIssuesInput) ([]IssueSummary, error)
func (*Gateway) ListOpenPullRequests ¶
func (g *Gateway) ListOpenPullRequests(ctx context.Context, input ListOpenPullRequestsInput) ([]PullRequestSummary, error)
func (*Gateway) ListPullRequestCheckRuns ¶ added in v0.9.0
func (g *Gateway) ListPullRequestCheckRuns(ctx context.Context, input PullRequestCheckRunsInput) (PullRequestCheckRuns, error)
func (*Gateway) ListPullRequestReviewState ¶ added in v0.8.0
func (g *Gateway) ListPullRequestReviewState(ctx context.Context, input PullRequestReviewStateInput) (PullRequestReviewState, error)
func (*Gateway) ListReviewRequestedPullRequests ¶ added in v0.9.6
func (g *Gateway) ListReviewRequestedPullRequests(ctx context.Context, input ListReviewRequestedPullRequestsInput) ([]PullRequestSummary, error)
func (*Gateway) ListReviewThreads ¶
func (g *Gateway) ListReviewThreads(ctx context.Context, input ListReviewThreadsInput) ([]ReviewThread, error)
func (*Gateway) ListSubIssues ¶ added in v0.8.0
func (g *Gateway) ListSubIssues(ctx context.Context, input ViewIssueInput) ([]DependencyIssue, error)
func (*Gateway) RemoveIssueLabels ¶ added in v0.7.1
func (g *Gateway) RemoveIssueLabels(ctx context.Context, input IssueLabelsInput) error
func (*Gateway) RemovePullRequestLabels ¶
func (g *Gateway) RemovePullRequestLabels(ctx context.Context, input PullRequestLabelsInput) error
func (*Gateway) RemovePullRequestReaction ¶
func (g *Gateway) RemovePullRequestReaction(ctx context.Context, input PullRequestReactionInput) error
func (*Gateway) ResolveReviewThread ¶
func (g *Gateway) ResolveReviewThread(ctx context.Context, input ResolveReviewThreadInput) error
func (*Gateway) SubmitReview ¶
func (g *Gateway) SubmitReview(ctx context.Context, input SubmitReviewInput) error
func (*Gateway) UpdateIssueComment ¶
func (g *Gateway) UpdateIssueComment(ctx context.Context, input UpdateIssueCommentInput) error
func (*Gateway) UpdatePullRequestBody ¶ added in v0.7.1
func (g *Gateway) UpdatePullRequestBody(ctx context.Context, input UpdatePullRequestBodyInput) error
func (*Gateway) UpdatePullRequestTitle ¶
func (g *Gateway) UpdatePullRequestTitle(ctx context.Context, input UpdatePullRequestTitleInput) error
func (*Gateway) ViewIssue ¶
func (g *Gateway) ViewIssue(ctx context.Context, input ViewIssueInput) (IssueDetail, error)
func (*Gateway) ViewPullRequest ¶
func (g *Gateway) ViewPullRequest(ctx context.Context, input ViewPullRequestInput) (PullRequestDetail, error)
func (*Gateway) ViewPullRequestMergeWatch ¶ added in v0.9.0
func (g *Gateway) ViewPullRequestMergeWatch(ctx context.Context, input ViewPullRequestInput) (PullRequestDetail, error)
func (*Gateway) ViewReviewThread ¶ added in v0.7.4
func (g *Gateway) ViewReviewThread(ctx context.Context, input ViewReviewThreadInput) (ReviewThread, error)
type GetPullRequestDiffInput ¶
type GitHubUser ¶ added in v0.9.0
type InitializeLabelsInput ¶
type IssueAssigneesInput ¶
type IssueCommentInput ¶
type IssueCommentResult ¶
type IssueDependency ¶ added in v0.8.0
type IssueDetail ¶
type IssueDetail struct {
Number int64
Title string
Body string
URL string
State string
StateReason string
CreatedAt string
UpdatedAt string
ClosedAt string
Author string
AuthorAssociation string
Assignees []string
AssigneeUsers []GitHubUser
Labels []string
IsPullRequest bool
CommentCount int
Comments []CommentInfo
}
type IssueLabelsInput ¶ added in v0.7.1
type IssueReaction ¶ added in v0.8.0
type IssueReactionInput ¶ added in v0.8.0
type IssueRepository ¶ added in v0.8.0
type IssueState ¶ added in v0.8.0
type IssueSummary ¶
type IssueTimelineInput ¶ added in v0.8.0
type LabelDefinition ¶
type LabelDefinition struct {
Name string `json:"name"`
Color string `json:"color"`
Description string `json:"description"`
}
func StandardLooperLabels ¶
func StandardLooperLabels() []LabelDefinition
type LabelInitItem ¶
type LabelInitResult ¶
type LabelInitResult struct {
Repo string `json:"repo"`
DryRun bool `json:"dryRun"`
Labels []LabelInitItem `json:"labels"`
Summary LabelInitSummary `json:"summary"`
}
type LabelInitSummary ¶
type LinkedPullRequest ¶ added in v0.8.0
type LinkedPullRequestsInput ¶ added in v0.8.0
type ListIssueBlockedByInput ¶ added in v0.8.0
type ListOpenIssuesInput ¶
type ListReviewRequestedPullRequestsInput ¶ added in v0.9.6
type ListReviewThreadsInput ¶
type PullRequestAutoMerge ¶ added in v0.9.0
type PullRequestCheckRun ¶ added in v0.9.0
type PullRequestCheckRuns ¶ added in v0.9.0
type PullRequestCheckRuns struct {
TotalCount int
CheckRuns []PullRequestCheckRun
Statuses []PullRequestStatus
}
type PullRequestCheckRunsInput ¶ added in v0.9.0
type PullRequestCommentInput ¶
type PullRequestDetail ¶
type PullRequestDetail struct {
Number int64
Title string
Body string
URL string
State string
CreatedAt string
UpdatedAt string
ClosedAt string
IsDraft bool
ReviewDecision string
Labels []string
HeadRefName string
BaseRefName string
HeadSHA string
BaseSHA string
Author string
AuthorAssociation string
CommentCount int
ReviewRequests []string
ReviewRequestUsers []GitHubUser
HasConflicts bool
Comments []map[string]any
IssueComments []CommentInfo
Reviews []map[string]any
Checks []map[string]any
Mergeable *bool
MergeableState string
MergedAt string
AutoMerge *PullRequestAutoMerge
}
type PullRequestLabelsInput ¶
type PullRequestReviewState ¶ added in v0.8.0
type PullRequestReviewStateInput ¶ added in v0.8.0
type PullRequestStatus ¶ added in v0.9.0
type PullRequestSummary ¶
type PullRequestSummary struct {
Number int64
Title string
URL string
State string
UpdatedAt string
IsDraft bool
ReviewDecision string
Labels []string
HeadRefName string
BaseRefName string
HeadSHA string
BaseSHA string
HasConflicts bool
Author string
AuthorAssociation string
ReviewRequests []string
ReviewRequestUsers []GitHubUser
Reviews []map[string]any
}
type RepositoryPermissionInput ¶ added in v0.8.0
type RepositorySettings ¶ added in v0.8.0
type RepositorySettingsInput ¶ added in v0.8.0
type ReviewComment ¶
type ReviewMarkerResult ¶
type ReviewThread ¶
type ReviewThreadComment ¶
type ReviewThreadNotFoundError ¶
type ReviewThreadNotFoundError struct {
ThreadID string
}
func (*ReviewThreadNotFoundError) Error ¶
func (e *ReviewThreadNotFoundError) Error() string
type SubmitReviewInput ¶
type SubmitReviewInput struct {
Repo string
PRNumber int64
Event string
Body string
CommitID string
Comments []ReviewComment
Anchors *diffanchor.Index
Disclosure config.DisclosureConfig
CWD string
}
type TransientError ¶
type TransientError struct {
Err error
}
func (*TransientError) Error ¶
func (e *TransientError) Error() string
func (*TransientError) Unwrap ¶
func (e *TransientError) Unwrap() error